@@ -16,7 +16,8 @@ setClass("Mefa",
         taxa = "MefaDataFrame",
         join = "character"),
     prototype = list(
-        xtab = as(matrix(0,0,0), "dgCMatrix"),
+        # xtab = as(matrix(0,0,0), "dgCMatrix"),
+        xtab = as(as(as(matrix(0,0,0), "dMatrix"), "generalMatrix"), "CsparseMatrix"),
         samp = NULL,
         taxa = NULL,
         join = "left"),
